@@ -12,7 +12,7 @@
 # Usage message.
 arUsage() {
 	tee >&2 << EOF
-usage: autorevision {-t output-type | -s symbol} [-o cache-file [-f] ] [-e name] [-U] [-V]
+usage: autorevision {-t output-type | -s symbol} [-o cache-file [-f] ] [-e name] [-U] [-q] [-V]
 	Options include:
 	-t output-type		= specify output type
 	-s symbol		= specify symbol output
@@ -20,6 +20,7 @@ usage: autorevision {-t output-type | -s symbol} [-o cache-file [-f] ] [-e name]
 	-f			= force the use of cache data
 	-e name			= set a different output name for VCS_EXTRA
 	-U			= check for untracked files in svn
+	-q			= Silence warnings
 	-V			= emit version and exit
 	-?			= help message
 
@@ -44,6 +45,7 @@ The following are valid output types:
 	py			= Python file
 	rpm			= rpm file
 	scheme			= scheme file
+	sed			= sed script
 	sh			= Bash sytax
 	swift			= Swift file
 	tex			= (La)TeX file
@@ -58,9 +60,11 @@ The following are valid symbols:
 	VCS_DATE
 	VCS_BRANCH
 	VCS_TAG
+	VCS_TAG_OPENPGP
 	VCS_TICK
 	VCS_EXTRA
 	VCS_FULL_HASH
+	VCS_COMMIT_OPENPGP
 	VCS_SHORT_HASH
 	VCS_WC_MODIFIED
 	VCS_ACTION_STAMP
@@ -70,7 +74,7 @@ EOF
 
 # Config
 ARVERSION="&&ARVERSION&&"
-while getopts ":t:o:s:e:VfU" OPTION; do
+while getopts ":t:o:s:e:VfqU" OPTION; do
 	case "${OPTION}" in
 		t)
 			AFILETYPE="${OPTARG}"
@@ -90,6 +94,9 @@ while getopts ":t:o:s:e:VfU" OPTION; do
 		U)
 			UNTRACKEDFILES="1"
 		;;
+		q)
+			WARNHIDE="1"
+		;;
 		V)
 			echo "autorevision ${ARVERSION}"
 			exit 0
@@ -136,6 +143,7 @@ fi
 
 GENERATED_HEADER="Generated by autorevision - do not hand-hack!"
 : "${EXTRA_NAME:="VCS_EXTRA"}"
+: "${WARNHIDE:="0"}"
 
 # Functions to extract data from different repo types.
 # For git repos
@@ -163,7 +171,9 @@ gitRepo() {
 	# Enumeration of changesets
 	VCS_NUM="$(git rev-list --count "${currentRev}" 2>/dev/null)"
 	if [ -z "${VCS_NUM}" ]; then
-		echo "warning: Counting the number of revisions may be slower due to an outdated git version less than 1.7.2.3. If something breaks, please update it." 1>&2
+		if [ ! "${WARNHIDE}" = "1" ]; then
+			echo "warning: Counting the number of revisions may be slower due to an outdated git version less than 1.7.2.3. If something breaks, please update it." 1>&2
+		fi
 		VCS_NUM="$(git rev-list HEAD | wc -l)"
 	fi
 
@@ -180,6 +190,9 @@ gitRepo() {
 		VCS_SHORT_HASH="${VCS_FULL_HASH}"
 	fi
 
+	# Get the current revision's signing key.
+	VCS_COMMIT_OPENPGP="$(git verify-commit --raw "${currentRev}" 2>&1 | grep "VALIDSIG" | cut -d ' ' -f 12)"
+
 	# Current branch
 	VCS_BRANCH="$(git rev-parse --symbolic-full-name --verify "$(git name-rev --name-only --no-undefined "${currentRev}" 2>/dev/null)" 2>/dev/null | sed -e 's:refs/heads/::' | sed -e 's:refs/::')"
 
@@ -189,6 +202,18 @@ gitRepo() {
 	# Current or last tag ancestor (empty if no tags)
 	VCS_TAG="$(echo "${DESCRIPTION}" | sed -e "s:-g${VCS_SHORT_HASH}\$::" -e 's:-[0-9]*$::')"
 
+	# Determine if the tag is annotated.
+	${LOCAL} tagType="$(git for-each-ref --format='%(objecttype)' "$(git rev-parse --symbolic-full-name --verify "${VCS_TAG}")")"
+	if [ ! "${tagType}" = "tag" ]; then
+		# Let the user know if the current tag is not annotated.
+		if [ ! "${WARNHIDE}" = "1" ]; then
+		echo "note: The most recent tag is not annotated; if it is intended to be a release you may want to fix this." 1>&2
+		fi
+	else
+		# You cannot have a signed tag that is not annotated.
+		VCS_TAG_OPENPGP="$(git verify-tag --raw "${VCS_TAG}" 2>&1 | grep "VALIDSIG" | cut -d ' ' -f 12)"
+	fi
+
 	# Distance to last tag or an alias of VCS_NUM if there is no tag
 	if [ ! -z "${DESCRIPTION}" ]; then
 		VCS_TICK="$(echo "${DESCRIPTION}" | sed -e "s:${VCS_TAG}-::" -e "s:-g${VCS_SHORT_HASH}::")"
@@ -199,7 +224,9 @@ gitRepo() {
 	# Date of the current commit
 	VCS_DATE="$(TZ=UTC git show -s --date=iso-strict-local --pretty=format:%cd "${currentRev}" 2>/dev/null | sed -e 's|+00:00|Z|')"
 	if [ -z "${VCS_DATE}" ]; then
-		echo "warning: Action stamps require git version 2.7+." 1>&2
+		if [ ! "${WARNHIDE}" = "1" ]; then
+			echo "warning: Action stamps require git version 2.7+." 1>&2
+		fi
 		VCS_DATE="$(git log -1 --pretty=format:%ci "${currentRev}" | sed -e 's: :T:' -e 's: ::' -e 's|+00:00|Z|')"
 		${LOCAL} ASdis="1"
 	fi
@@ -429,11 +456,13 @@ VCS_NUM="${VCS_NUM}"
 VCS_DATE="${VCS_DATE}"
 VCS_BRANCH="${VCS_BRANCH}"
 VCS_TAG="${VCS_TAG}"
+VCS_TAG_OPENPGP="${VCS_TAG_OPENPGP}"
 VCS_TICK="${VCS_TICK}"
 ${EXTRA_NAME}="${VCS_EXTRA}"
 
 VCS_ACTION_STAMP="${VCS_ACTION_STAMP}"
 VCS_FULL_HASH="${VCS_FULL_HASH}"
+VCS_COMMIT_OPENPGP="${VCS_COMMIT_OPENPGP}"
 VCS_SHORT_HASH="${VCS_SHORT_HASH}"
 
 VCS_WC_MODIFIED="${VCS_WC_MODIFIED}"
@@ -447,21 +476,23 @@ cOutput() {
 	tee << EOF
 /* ${GENERATED_HEADER} */
 
-const char *VCS_TYPE         = "${VCS_TYPE}";
-const char *VCS_BASENAME     = "${VCS_BASENAME}";
-const char *VCS_UUID         = "${VCS_UUID}";
-const int VCS_NUM            = ${VCS_NUM};
-const char *VCS_DATE         = "${VCS_DATE}";
-const char *VCS_BRANCH       = "${VCS_BRANCH}";
-const char *VCS_TAG          = "${VCS_TAG}";
-const int VCS_TICK           = ${VCS_TICK};
-const char *${EXTRA_NAME}        = "${VCS_EXTRA}";
+const char *VCS_TYPE      	 	 = "${VCS_TYPE}";
+const char *VCS_BASENAME    	 = "${VCS_BASENAME}";
+const char *VCS_UUID			 = "${VCS_UUID}";
+const int VCS_NUM				 = ${VCS_NUM};
+const char *VCS_DATE        	 = "${VCS_DATE}";
+const char *VCS_BRANCH      	 = "${VCS_BRANCH}";
+const char *VCS_TAG         	 = "${VCS_TAG}";
+const char *VCS_TAG_OPENPGP		 = "${VCS_TAG_OPENPGP}";
+const int VCS_TICK				 = ${VCS_TICK};
+const char *${EXTRA_NAME}		 = "${VCS_EXTRA}";
 
-const char *VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}";
-const char *VCS_FULL_HASH    = "${VCS_FULL_HASH}";
-const char *VCS_SHORT_HASH   = "${VCS_SHORT_HASH}";
+const char *VCS_ACTION_STAMP	 = "${VCS_ACTION_STAMP}";
+const char *VCS_FULL_HASH   	 = "${VCS_FULL_HASH}";
+const char *VCS_COMMIT_OPENPGP	 = "${VCS_COMMIT_OPENPGP}";
+const char *VCS_SHORT_HASH		 = "${VCS_SHORT_HASH}";
 
-const int VCS_WC_MODIFIED     = ${VCS_WC_MODIFIED};
+const int VCS_WC_MODIFIED		 = ${VCS_WC_MODIFIED};
 
 /* end */
 EOF
@@ -479,11 +510,13 @@ set(VCS_NUM ${VCS_NUM})
 set(VCS_DATE ${VCS_DATE})
 set(VCS_BRANCH ${VCS_BRANCH})
 set(VCS_TAG ${VCS_TAG})
+set(VCS_TAG_OPENPGP ${VCS_TAG_OPENPGP})
 set(VCS_TICK ${VCS_TICK})
 set(${EXTRA_NAME} ${VCS_EXTRA})
 
 set(VCS_ACTION_STAMP ${VCS_ACTION_STAMP})
 set(VCS_FULL_HASH ${VCS_FULL_HASH})
+set(VCS_COMMIT_OPENPGP ${VCS_COMMIT_OPENPGP})
 set(VCS_SHORT_HASH ${VCS_SHORT_HASH})
 
 set(VCS_WC_MODIFIED ${VCS_WC_MODIFIED})
@@ -506,11 +539,13 @@ hOutput() {
 #define VCS_DATE		"${VCS_DATE}"
 #define VCS_BRANCH		"${VCS_BRANCH}"
 #define VCS_TAG			"${VCS_TAG}"
+#define VCS_TAG_OPENPGP	"${VCS_TAG_OPENPGP}"
 #define VCS_TICK		${VCS_TICK}
 #define ${EXTRA_NAME}		"${VCS_EXTRA}"
 
 #define VCS_ACTION_STAMP	"${VCS_ACTION_STAMP}"
 #define VCS_FULL_HASH		"${VCS_FULL_HASH}"
+#define VCS_COMMIT_OPENPGP	"${VCS_COMMIT_OPENPGP}"
 #define VCS_SHORT_HASH		"${VCS_SHORT_HASH}"
 
 #define VCS_WC_MODIFIED		${VCS_WC_MODIFIED}
@@ -535,11 +570,13 @@ xcodeOutput() {
 #define VCS_DATE		${VCS_DATE}
 #define VCS_BRANCH		${VCS_BRANCH}
 #define VCS_TAG			${VCS_TAG}
+#define VCS_TAG_OPENPGP	${VCS_TAG_OPENPGP}
 #define VCS_TICK		${VCS_TICK}
 #define ${EXTRA_NAME}		${VCS_EXTRA}
 
 #define VCS_ACTION_STAMP	${VCS_ACTION_STAMP}
 #define VCS_FULL_HASH		${VCS_FULL_HASH}
+#define VCS_COMMIT_OPENPGP	${VCS_COMMIT_OPENPGP}
 #define VCS_SHORT_HASH		${VCS_SHORT_HASH}
 
 #define VCS_WC_MODIFIED		${VCS_WC_MODIFIED}
@@ -568,6 +605,11 @@ swiftOutput() {
 	else
 		VCS_TAG="\"${VCS_TAG}\""
 	fi
+	if [ -z "${VCS_TAG_OPENPGP}" ]; then
+		VCS_TAG_OPENPGP="nil"
+	else
+		VCS_TAG_OPENPGP="\"${VCS_TAG_OPENPGP}\""
+	fi
 	: "${VCS_TICK:="nil"}"
 	if [ -z "${VCS_EXTRA}" ]; then
 		VCS_EXTRA="nil"
@@ -579,21 +621,28 @@ swiftOutput() {
 	else
 		VCS_ACTION_STAMP="\"${VCS_ACTION_STAMP}\""
 	fi
+	if [ -z "${VCS_COMMIT_OPENPGP}" ]; then
+		VCS_COMMIT_OPENPGP="nil"
+	else
+		VCS_COMMIT_OPENPGP="\"${VCS_COMMIT_OPENPGP}\""
+	fi
 	tee << EOF
 /* ${GENERATED_HEADER} */
 
 let VCS_TYPE			= "${VCS_TYPE}"
 let VCS_BASENAME		= "${VCS_BASENAME}"
-let VCS_UUID:	String?	= ${VCS_UUID}
-let VCS_NUM:	Int		= ${VCS_NUM}
+let VCS_UUID:			String?	= ${VCS_UUID}
+let VCS_NUM:			Int		= ${VCS_NUM}
 let VCS_DATE			= "${VCS_DATE}"
-let VCS_BRANCH:	String	= "${VCS_BRANCH}"
-let VCS_TAG:	String?	= ${VCS_TAG}
-let VCS_TICK:	Int?	= ${VCS_TICK}
-let ${EXTRA_NAME}:	String?	= ${VCS_EXTRA}
+let VCS_BRANCH:			String	= "${VCS_BRANCH}"
+let VCS_TAG:			String?	= ${VCS_TAG}
+let VCS_TAG_OPENPGP:	String?	= ${VCS_TAG_OPENPGP}
+let VCS_TICK:			Int?	= ${VCS_TICK}
+let ${EXTRA_NAME}:		String?	= ${VCS_EXTRA}
 
 let VCS_ACTION_STAMP:	String?	= ${VCS_ACTION_STAMP}
 let VCS_FULL_HASH:		String	= "${VCS_FULL_HASH}"
+let VCS_COMMIT_OPENPGP:	String?	= ${VCS_COMMIT_OPENPGP}
 let VCS_SHORT_HASH:		String	= "${VCS_SHORT_HASH}"
 
 let VCS_WC_MODIFIED:	Bool	= ${VCS_WC_MODIFIED}
@@ -618,14 +667,16 @@ VCS_NUM = ${VCS_NUM}
 VCS_DATE = "${VCS_DATE}"
 VCS_BRANCH = "${VCS_BRANCH}"
 VCS_TAG = "${VCS_TAG}"
+VCS_TAG_OPENPGP = "${VCS_TAG_OPENPGP}"
 VCS_TICK = ${VCS_TICK}
 ${EXTRA_NAME} = "${VCS_EXTRA}"
 
 VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}"
 VCS_FULL_HASH = "${VCS_FULL_HASH}"
+VCS_COMMIT_OPENPGP = "${VCS_COMMIT_OPENPGP}"
 VCS_SHORT_HASH = "${VCS_SHORT_HASH}"
 
-VCS_WC_MODIFIED = ${PY_VCS_WC_MODIFIED}
+VCS_WC_MODIFIED = ${VCS_WC_MODIFIED}
 
 # end
 EOF
@@ -643,11 +694,13 @@ plOutput() {
 \$VCS_DATE = '${VCS_DATE}';
 \$VCS_BRANCH = '${VCS_BRANCH}';
 \$VCS_TAG = '${VCS_TAG}';
+\$VCS_TAG_OPENPGP = '${VCS_TAG_OPENPGP}';
 \$VCS_TICK = ${VCS_TICK};
 \$${EXTRA_NAME} = '${VCS_EXTRA}';
 
 \$VCS_ACTION_STAMP = '${VCS_ACTION_STAMP}';
 \$VCS_FULL_HASH = '${VCS_FULL_HASH}';
+\$VCS_COMMIT_OPENPGP = '${VCS_COMMIT_OPENPGP}';
 \$VCS_SHORT_HASH = '${VCS_SHORT_HASH}';
 
 \$VCS_WC_MODIFIED = ${VCS_WC_MODIFIED};
@@ -673,11 +726,13 @@ VCS_NUM = ${VCS_NUM}
 VCS_DATE = "${VCS_DATE}"
 VCS_BRANCH = "${VCS_BRANCH}"
 VCS_TAG = "${VCS_TAG}"
+VCS_TAG_OPENPGP = "${VCS_TAG_OPENPGP}"
 VCS_TICK = ${VCS_TICK}
 ${EXTRA_NAME} = "${VCS_EXTRA}"
 
 VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}"
 VCS_FULL_HASH = "${VCS_FULL_HASH}"
+VCS_COMMIT_OPENPGP = "${VCS_COMMIT_OPENPGP}"
 VCS_SHORT_HASH = "${VCS_SHORT_HASH}"
 
 VCS_WC_MODIFIED = ${VCS_WC_MODIFIED}
@@ -704,10 +759,12 @@ return array(
 	"VCS_DATE" => "${VCS_DATE}",
 	"VCS_BRANCH" => "${VCS_BRANCH}",
 	"VCS_TAG" => "${VCS_TAG}",
+	"VCS_TAG_OPENPGP" => "${VCS_TAG_OPENPGP}",
 	"VCS_TICK" => ${VCS_TICK},
 	"${EXTRA_NAME}" => "${VCS_EXTRA}",
 	"VCS_ACTION_STAMP" => "${VCS_ACTION_STAMP}",
 	"VCS_FULL_HASH" => "${VCS_FULL_HASH}",
+	"VCS_COMMIT_OPENPGP" => "${VCS_COMMIT_OPENPGP}",
 	"VCS_SHORT_HASH" => "${VCS_SHORT_HASH}",
 	"VCS_WC_MODIFIED" => ${VCS_WC_MODIFIED}
 );
@@ -733,10 +790,12 @@ VCS_NUM = ${VCS_NUM}
 VCS_DATE = "${VCS_DATE}"
 VCS_BRANCH = "${VCS_BRANCH}"
 VCS_TAG = "${VCS_TAG}"
+VCS_TAG_OPENPGP = "${VCS_TAG_OPENPGP}"
 VCS_TICK = ${VCS_TICK}
 ${EXTRA_NAME} = "${VCS_EXTRA}"
 VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}"
 VCS_FULL_HASH = "${VCS_FULL_HASH}"
+VCS_COMMIT_OPENPGP = "${VCS_COMMIT_OPENPGP}"
 VCS_SHORT_HASH = "${VCS_SHORT_HASH}"
 VCS_WC_MODIFIED = ${VCS_WC_MODIFIED}
 ; end
@@ -760,11 +819,13 @@ var autorevision = {
 	VCS_DATE: "${VCS_DATE}",
 	VCS_BRANCH: "${VCS_BRANCH}",
 	VCS_TAG: "${VCS_TAG}",
+	VCS_TAG_OPENPGP: "${VCS_TAG_OPENPGP}",
 	VCS_TICK: ${VCS_TICK},
 	${EXTRA_NAME}: "${VCS_EXTRA}",
 
 	VCS_ACTION_STAMP: "${VCS_ACTION_STAMP}",
 	VCS_FULL_HASH: "${VCS_FULL_HASH}",
+	VCS_COMMIT_OPENPGP: "${VCS_COMMIT_OPENPGP}",
 	VCS_SHORT_HASH: "${VCS_SHORT_HASH}",
 
 	VCS_WC_MODIFIED: ${VCS_WC_MODIFIED}
@@ -795,11 +856,13 @@ jsonOutput() {
 	"VCS_DATE": "${VCS_DATE}",
 	"VCS_BRANCH":"${VCS_BRANCH}",
 	"VCS_TAG": "${VCS_TAG}",
+	"VCS_TAG_OPENPGP": "${VCS_TAG_OPENPGP}",
 	"VCS_TICK": ${VCS_TICK},
 	"${EXTRA_NAME}": "${VCS_EXTRA}",
 
 	"VCS_ACTION_STAMP": "${VCS_ACTION_STAMP}",
 	"VCS_FULL_HASH": "${VCS_FULL_HASH}",
+	"VCS_COMMIT_OPENPGP": "${VCS_COMMIT_OPENPGP}",
 	"VCS_SHORT_HASH": "${VCS_SHORT_HASH}",
 
 	"VCS_WC_MODIFIED": ${VCS_WC_MODIFIED}
@@ -824,11 +887,13 @@ public class autorevision {
     public static final String VCS_DATE = "${VCS_DATE}";
     public static final String VCS_BRANCH = "${VCS_BRANCH}";
     public static final String VCS_TAG = "${VCS_TAG}";
+    public static final String VCS_TAG_OPENPGP = "${VCS_TAG_OPENPGP}";
     public static final long VCS_TICK = ${VCS_TICK};
     public static final String ${EXTRA_NAME} = "${VCS_EXTRA}";
 
     public static final String VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}";
     public static final String VCS_FULL_HASH = "${VCS_FULL_HASH}";
+    public static final String VCS_COMMIT_OPENPGP = "${VCS_COMMIT_OPENPGP}";
     public static final String VCS_SHORT_HASH = "${VCS_SHORT_HASH}";
 
     public static final boolean VCS_WC_MODIFIED = ${VCS_WC_MODIFIED};
@@ -858,10 +923,12 @@ namespace AutoRevision
         public static string VcsDate = "${VCS_DATE}";
         public static string VcsBranch = "${VCS_DATE}";
         public static string VcsTag = "${VCS_TAG}";
+        public static string VcsTagOpenpgp = "${VCS_TAG_OPENPGP}";
         public static string VcsTick = "${VCS_TICK}";
         public static string ${EXTRA_NAME} = "${VCS_EXTRA}";
         public static string VcsActionStamp = "${VCS_ACTION_STAMP}";
         public static string VcsFullHash = "${VCS_FULL_HASH}";
+        public static string VcsCommitOpenpgp = "${VCS_COMMIT_OPENPGP}";
         public static string VcsShortHash = "${VCS_SHORT_HASH}";
         public static string VcsWcModified = "${VCS_WC_MODIFIED}";
     }
@@ -885,11 +952,13 @@ VCS_NUM=${VCS_NUM}
 VCS_DATE=${VCS_DATE}
 VCS_BRANCH=${VCS_BRANCH}
 VCS_TAG=${VCS_TAG}
+VCS_TAG_OPENPGP=${VCS_TAG_OPENPGP}
 VCS_TICK=${VCS_TICK}
 ${EXTRA_NAME}=${VCS_EXTRA}
 
 VCS_ACTION_STAMP=${VCS_ACTION_STAMP}
 VCS_FULL_HASH=${VCS_FULL_HASH}
+VCS_COMMIT_OPENPGP=${VCS_COMMIT_OPENPGP}
 VCS_SHORT_HASH=${VCS_SHORT_HASH}
 
 VCS_WC_MODIFIED=${VCS_WC_MODIFIED}
@@ -907,16 +976,19 @@ define(\`VCS_NUM', \`${VCS_NUM}')dnl
 define(\`VCS_DATE', \`${VCS_DATE}')dnl
 define(\`VCS_BRANCH', \`${VCS_BRANCH}')dnl
 define(\`VCS_TAG', \`${VCS_TAG}')dnl
+define(\`VCS_TAG_OPENPGP', \`${VCS_TAG_OPENPGP}')dnl
 define(\`VCS_TICK', \`${VCS_TICK}')dnl
 define(\`${EXTRA_NAME}', \`${VCS_EXTRA}')dnl
 define(\`VCS_ACTIONSTAMP', \`${VCS_ACTION_STAMP}')dnl
 define(\`VCS_FULLHASH', \`${VCS_FULL_HASH}')dnl
+define(\`VCS_COMMIT_OPENPGP', \`${VCS_COMMIT_OPENPGP}')dnl
 define(\`VCS_SHORTHASH', \`${VCS_SHORT_HASH}')dnl
 define(\`VCS_WC_MODIFIED', \`${VCS_WC_MODIFIED}')dnl
 EOF
 }
 
 # For (La)TeX output
+# shellcheck disable=SC1117
 texOutput() {
 	case "${VCS_WC_MODIFIED}" in
 		0) VCS_WC_MODIFIED="false" ;;
@@ -934,10 +1006,12 @@ texOutput() {
 \def \vcsDate {${VCS_DATE}}
 \def \vcsBranch {${VCS_BRANCH}}
 \def \vcsTag {${VCS_TAG}}
+\def \vcsTagOpenpgp {${VCS_TAG_OPENPGP}}
 \def \vcsTick {${VCS_TICK}}
 \def \\${EXTRA_NAME} {${VCS_EXTRA}}
 \def \vcsACTIONSTAMP {${VCS_ACTION_STAMP}}
 \def \vcsFullHash {${VCS_FULL_HASH}}
+\def \vcsCommitOpenpgp {${VCS_COMMIT_OPENPGP}}
 \def \vcsShortHash {${VCS_SHORT_HASH}}
 \def \vcsWCModified {${VCS_WC_MODIFIED}}
 \endinput
@@ -959,12 +1033,14 @@ schemeOutput() {
 (define VCS_DATE        "${VCS_DATE}")
 (define VCS_BRANCH      "${VCS_BRANCH}")
 (define VCS_TAG         "${VCS_TAG}")
+(define VCS_TAG_OPENPGP "${VCS_TAG_OPENPGP}")
 (define VCS_TICK        ${VCS_TICK})
-(define ${EXTRA_NAME}       "${VCS_EXTRA}")
+(define ${EXTRA_NAME}   "${VCS_EXTRA}")
 
 (define VCS_ACTION_STAMP   "${VCS_ACTION_STAMP}")
-(define VCS_FULL_HASH   "${VCS_FULL_HASH}")
-(define VCS_SHORT_HASH  "${VCS_SHORT_HASH}")
+(define VCS_FULL_HASH      "${VCS_FULL_HASH}")
+(define VCS_COMMIT_OPENPGP "${VCS_COMMIT_OPENPGP}")
+(define VCS_SHORT_HASH     "${VCS_SHORT_HASH}")
 
 (define VCS_WC_MODIFIED ${VCS_WC_MODIFIED})
 ;; end
@@ -986,11 +1062,13 @@ clojureOutput() {
 (def VCS_DATE        "${VCS_DATE}")
 (def VCS_BRANCH      "${VCS_BRANCH}")
 (def VCS_TAG         "${VCS_TAG}")
+(def VCS_TAG_OPENPGP "${VCS_TAG_OPENPGP}")
 (def VCS_TICK        ${VCS_TICK})
 (def ${EXTRA_NAME}       "${VCS_EXTRA}")
 
 (def VCS_ACTION_STAMP   "${VCS_ACTION_STAMP}")
 (def VCS_FULL_HASH      "${VCS_FULL_HASH}")
+(def VCS_COMMIT_OPENPGP "${VCS_COMMIT_OPENPGP}")
 (def VCS_SHORT_HASH     "${VCS_SHORT_HASH}")
 
 (def VCS_WC_MODIFIED ${VCS_WC_MODIFIED})
@@ -1008,12 +1086,14 @@ $([ "${VCS_UUID}" ] && echo "%define vcs_uuid		${VCS_UUID}")
 $([ "${VCS_NUM}" ] && echo "%define vcs_num			${VCS_NUM}")
 $([ "${VCS_DATE}" ] && echo "%define vcs_date		${VCS_DATE}")
 $([ "${VCS_BRANCH}" ] && echo "%define vcs_branch		${VCS_BRANCH}")
+$([ "${VCS_TAG_OPENPGP}" ] && echo "%define vcs_tag_openpgp			${VCS_TAG_OPENPGP}")
 $([ "${VCS_TAG}" ] && echo "%define vcs_tag			${VCS_TAG}")
 $([ "${VCS_TICK}" ] && echo "%define vcs_tick		${VCS_TICK}")
 $([ "${VCS_EXTRA}" ] && echo "%define ${EXTRA_NAME}		${VCS_EXTRA}")
 
 $([ "${VCS_ACTION_STAMP}" ] && echo "%define vcs_action_stamp		${VCS_ACTION_STAMP}")
 $([ "${VCS_FULL_HASH}" ] && echo "%define vcs_full_hash		${VCS_FULL_HASH}")
+$([ "${VCS_COMMIT_OPENPGP}" ] && echo "%define vcs_commit_openpgp		${VCS_COMMIT_OPENPGP}")
 $([ "${VCS_SHORT_HASH}" ] && echo "%define vcs_short_hash		${VCS_SHORT_HASH}")
 
 $([ "${VCS_WC_MODIFIED}" ] && echo "%define vcs_wc_modified		${VCS_WC_MODIFIED}")
@@ -1035,19 +1115,21 @@ hppOutput() {
 
 namespace $(echo "${NAMESPACE}" | tr '[:upper:]' '[:lower:]')
 {
-	const std::string VCS_TYPE		= "${VCS_TYPE}";
-	const std::string VCS_BASENAME	= "${VCS_BASENAME}";
-	const std::string VCS_UUID		= "${VCS_UUID}";
-	const int VCS_NUM				= ${VCS_NUM};
-	const std::string VCS_DATE		= "${VCS_DATE}";
-	const std::string VCS_BRANCH	= "${VCS_BRANCH}";
-	const std::string VCS_TAG		= "${VCS_TAG}";
-	const int VCS_TICK				= ${VCS_TICK};
+	const std::string VCS_TYPE			= "${VCS_TYPE}";
+	const std::string VCS_BASENAME		= "${VCS_BASENAME}";
+	const std::string VCS_UUID			= "${VCS_UUID}";
+	const int VCS_NUM					= ${VCS_NUM};
+	const std::string VCS_DATE			= "${VCS_DATE}";
+	const std::string VCS_BRANCH		= "${VCS_BRANCH}";
+	const std::string VCS_TAG			= "${VCS_TAG}";
+	const std::string VCS_TAG_OPENPGP	= "${VCS_TAG_OPENPGP}";
+	const int VCS_TICK					= ${VCS_TICK};
 	const std::string ${EXTRA_NAME}		= "${VCS_EXTRA}";
 
-	const std::string VCS_ACTION_STAMP	= "${VCS_ACTION_STAMP}";
-	const std::string VCS_FULL_HASH		= "${VCS_FULL_HASH}";
-	const std::string VCS_SHORT_HASH	= "${VCS_SHORT_HASH}";
+	const std::string VCS_ACTION_STAMP		= "${VCS_ACTION_STAMP}";
+	const std::string VCS_FULL_HASH			= "${VCS_FULL_HASH}";
+	const std::string VCS_COMMIT_OPENPGP	= "${VCS_COMMIT_OPENPGP}";
+	const std::string VCS_SHORT_HASH		= "${VCS_SHORT_HASH}";
 
 	const int VCS_WC_MODIFIED			= ${VCS_WC_MODIFIED};
 }
@@ -1074,11 +1156,13 @@ VCS_NUM = ${VCS_NUM};
 VCS_DATE = '${VCS_DATE}';
 VCS_BRANCH = '${VCS_BRANCH}';
 VCS_TAG = '${VCS_TAG}';
+VCS_TAG_OPENPGP = '${VCS_TAG_OPENPGP}';
 VCS_TICK = ${VCS_TICK};
 ${EXTRA_NAME} = '${VCS_EXTRA}';
 
 VCS_ACTION_STAMP = '${VCS_ACTION_STAMP}';
 VCS_FULL_HASH = '${VCS_FULL_HASH}';
+VCS_COMMIT_OPENPGP = '${VCS_COMMIT_OPENPGP}';
 VCS_SHORT_HASH = '${VCS_SHORT_HASH}';
 
 VCS_WC_MODIFIED = ${VCS_WC_MODIFIED};
@@ -1099,11 +1183,13 @@ VCS_NUM = ${VCS_NUM};
 VCS_DATE = '${VCS_DATE}';
 VCS_BRANCH = '${VCS_BRANCH}';
 VCS_TAG = '${VCS_TAG}';
+VCS_TAG_OPENPGP = '${VCS_TAG_OPENPGP}';
 VCS_TICK = ${VCS_TICK};
 ${EXTRA_NAME} = '${VCS_EXTRA}';
 
 VCS_ACTION_STAMP = '${VCS_ACTION_STAMP}';
 VCS_FULL_HASH = '${VCS_FULL_HASH}';
+VCS_COMMIT_OPENPGP = '${VCS_COMMIT_OPENPGP}';
 VCS_SHORT_HASH = '${VCS_SHORT_HASH}';
 
 VCS_WC_MODIFIED = ${VCS_WC_MODIFIED};
@@ -1112,6 +1198,31 @@ VCS_WC_MODIFIED = ${VCS_WC_MODIFIED};
 EOF
 }
 
+sedOutput() {
+	tee << EOF
+# ${GENERATED_HEADER}
+
+s|@VCS_TYPE@|${VCS_TYPE}|g
+s|@VCS_BASENAME@|${VCS_BASENAME}|g
+s|@VCS_UUID@|${VCS_UUID}|g
+s|@VCS_NUM@|${VCS_NUM}|g
+s|@VCS_DATE@|${VCS_DATE}|g
+s|@VCS_BRANCH@|${VCS_BRANCH}|g
+s|@VCS_TAG@|${VCS_TAG}|g
+s|@VCS_TAG_OPENPGP@|${VCS_TAG_OPENPGP}|g
+s|@VCS_TICK@|${VCS_TICK}|g
+s|@${EXTRA_NAME}@|${VCS_EXTRA}|g
+
+s|@VCS_ACTION_STAMP@|${VCS_ACTION_STAMP}|g
+s|@VCS_FULL_HASH@|${VCS_FULL_HASH}|g
+s|@VCS_COMMIT_OPENPGP@|${VCS_COMMIT_OPENPGP}|g
+s|@VCS_SHORT_HASH@|${VCS_SHORT_HASH}|g
+
+s|@VCS_WC_MODIFIED@|${VCS_WC_MODIFIED}|g
+
+# end
+EOF
+}
 
 # Helper functions
 # Count path segments
@@ -1296,6 +1407,8 @@ if [ ! -z "${AFILETYPE}" ]; then
 		xcodeOutput
 	elif [ "${AFILETYPE}" = "swift" ]; then
 		swiftOutput
+	elif [ "${AFILETYPE}" = "sed" ]; then
+		sedOutput
 	elif [ "${AFILETYPE}" = "sh" ]; then
 		shOutput
 	elif [ "${AFILETYPE}" = "py" ] || [ "${AFILETYPE}" = "python" ]; then
